import re
import time

from ats_base.common import func
from ats_base.log.logger import logger
from ats_base.service import app, pro, em, udm, build_in

from ats_case.case.context import Context
from ats_case.common.enum import *
from ats_case.common.error import *

"""
    常用操作命令
"""


def send(context: Context, todo: dict, types=2, retry_times: int = 3):
    """
    发送操作命令 - 向测试端app
    :param context:         上下文
    :param todo:            任务
    :param types:
    :param retry_times:     失败重试次数（默认：3次）
    :return:
    """
    result = None

    try:
        data = {
            'type': types,
            'exec_time': func.sys_current_time(),
            'test_sn': context.test_sn,
            'case_id': context.case.id,
            'meter_pos': context.meter.pos,
            'step_id': context.runtime.step,
            'todo': todo
        }

        logger.info('~ @TCC-SEND-> client:{} data:{}'.format(context.tester.api, data))
        result = app.send(context.tester.api, data)
        logger.info('~ @TCC-SEND<- result:{}'.format(result))
    # except requests.exceptions.MissingSchema as me:
    #     logger.error(str(me))
    #     raise AssertionError(str(me))
    except Exception as ae:
        logger.error(str(ae))

        retry_times -= 1
        if retry_times <= 0:
            raise APIError(context.tester.api)
        else:
            sleep(5)
            send(context, todo, types, retry_times)

    return result


def sleep(seconds: float):
    """
    休眠
    :param seconds:     秒
    :return:
    """
    logger.info('~ @TCC-SLEEP-> {}secs'.format(seconds))
    time.sleep(seconds)


def offbench(context: Context, disabled=1):
    """
    脱表台
    :param context:
    :param disabled:     使能
    :return:
    """
    clazz = OperationClazz(context.case.steps[str(context.runtime.step)].get('type'))

    if disabled == 1:
        if clazz == OperationClazz.BENCH:
            return True

    return False


"""
    内部方法
"""


def _replace(context: Context, data: dict):
    sd = str(data)
    sd = sd.replace('$', '"')

    re_list = re.findall(r"#(.+?)\'", sd)
    for r in re_list:
        v = eval(r)
        if type(v) is str:
            sd = sd.replace('#{}'.format(r), v)
        else:
            sd = sd.replace('\'#{}\''.format(r), str(v))

    re_list = re.findall(r"&(.+?)\'", sd)
    for r in re_list:
        sd = sd.replace(r, '{}:{}:{}:{}'.format(context.test_sn, context.case.id, context.meter.pos, r))

    return eval(sd)


def _replace_bench0(context: Context, data: dict):
    sd = str(data)

    re_list = re.findall(r"#(.+?)\'", sd)
    for r in re_list:
        v = eval(r)
        if type(v) is str:
            sd = sd.replace('#{}'.format(r), v)
        else:
            sd = sd.replace('\'#{}\''.format(r), str(v))

    return eval(sd)


def _replace_bench1(data: dict, v_data: dict):
    sd = str(data)

    re_list = re.findall(r"&(.+?)\'", sd)
    for r in re_list:
        v = v_data[r]
        if type(v) is str:
            sd = sd.replace('&{}'.format(r), v)
        else:
            sd = sd.replace('\'&{}\''.format(r), str(v))

    return eval(sd)


def step_annotation(**param):
    """
    测试步骤方法注释 - 装饰器
    :param param: desc-测试步骤描述
    :return:
    """
    desc = param.get('desc')

    def decorate(callback):
        def fn(*args, **kwargs):
            client().message(desc).show(args[0])  # send(args[0], todo={'app:show': {'msg': desc}})
            r = callback(*args, **kwargs)
            return r

        return fn

    return decorate


"""
    通讯协议篇
"""


def meter(protocol: str):
    return Meter(protocol)


class Meter(object):
    def __init__(self, protocol):
        self._protocol = ProClazz(protocol)
        self._comm_addr = None
        self._operation = None
        self._element = None
        self._parameter = None
        self._addition = None
        self._security = None
        self._frame = None
        self._parse = None
        self._func_module = None
        self._func = None
        self._expect_result = None
        self._func_parameter = {}

    def comm_addr(self, addr: str):
        self._comm_addr = addr
        return self

    def operation(self, op: str):
        self._operation = op
        return self

    def element(self, di):
        self._element = di
        return self

    def parameter(self, param=None):
        self._parameter = param
        return self

    def addition(self, addi=None):
        self._addition = addi
        return self

    def security(self, se=None):
        self._security = se
        return self

    def compare(self, data):
        self._func_module = data.get('module')
        self._func = data.get('code')
        self._expect_result = data.get('expect_result', None)
        self._func_parameter = data.get('parameter', {})

        return self

    def frame(self, hexStr: str):
        self._frame = hexStr
        return self

    def encode(self, context: Context):
        logger.info(
            '~ @PRO-ENCODE-> protocol:{} comm_addr:{} operation:{} element:{}'.format(self._protocol,
                                                                                      self._comm_addr,
                                                                                      self._operation,
                                                                                      self._element))
        if type(self._parameter) is dict:
            self._parameter = _replace(context, self._parameter)

        parse = pro.encode(func.to_dict(protocol=self._protocol.name, comm_addr=self._comm_addr,
                                        operation=self._operation, element=self._element, parameter=self._parameter,
                                        addition=self._addition, security=self._security,
                                        session_key=context.test_sn))
        logger.info('~ @PRO-ENCODE<- protocol:{} frame:{}'.format(self._protocol, parse.get('frame')))

        self._frame = parse.get('frame')
        return self._frame

    def decode(self, context: Context, index=0):
        # 异常判断 - 客户端返回结果
        if self._frame is None or len(self._frame) <= 0:
            # raise ClientError(self._frame)
            self._parse = '无响应帧'
            return

        logger.info('~ @PRO-DECODE-> protocol:{} frame:{}'.format(self._protocol, self._frame))
        data = pro.decode(
            func.to_dict(protocol=self._protocol.name, frame=self._frame, session_key=context.test_sn))
        logger.info('~ @PRO-DECODE<- protocol:{} parse:{}'.format(self._protocol, data))

        # 异常判断 - 协议服务返回结果
        if data.get('error') == 1:
            raise MeterOperationError(data.get('result'))

        # 分帧处理开始
        next_frame = data.get('next_frame', None)
        if next_frame is not None:
            result = send(context,
                          todo={'meter:comm': {'channel': context.case.steps[str(context.runtime.step)].get('channel'),
                                               'frame': next_frame}})
            self._frame = result.get('result')
            self.decode(context, index + 1)
        else:
            context.runtime.final_result = data.get('result')
        # 分帧处理结束

        if index == 0:
            self._parse = context.runtime.final_result
            self._flush(context)
            return self._parse

    def _flush(self, context: Context):
        context.runtime.steps.update({context.runtime.step: func.to_dict(obj='meter', op=self._operation
                                                                         , element=self._element
                                                                         , parameter=self._parameter,
                                                                         result=self._parse)})

    def acv(self, context: Context):
        result = str(self._parse)
        if self._func is not None:
            if type(self._func_parameter) is dict:
                self._func_parameter = _replace(context, self._func_parameter)
            try:
                if self._expect_result is None:
                    expect_result = context.runtime.steps[context.runtime.step - 1]
                else:
                    expect_result = context.runtime.steps[int(self._expect_result)]
            except:
                expect_result = None
            data = func.to_dict(result=self._parse, expect_result=expect_result, parameter=self._func_parameter)

            logger.info('~ @ACD-> module:{} function:{} parameter:{}'.format(
                self._func_module, self._func, self._func_parameter))
            result = udm.handle(module='meter.{}'.format(self._func_module), function=self._func
                                , data=data, debug_url=context.acd_url)
            logger.info('~ @ACD<- module:{} function:{} result:{}'.format(self._func_module, self._func, result))

            context.runtime.acvs[context.runtime.step] = result

        return result

    def exec(self, context: Context):
        self.encode(context)
        result = send(context,
                      todo={'meter:comm': {'channel': context.case.steps[str(context.runtime.step)].get('channel'),
                                           'frame': self._frame}})
        self._frame = result.get('result')
        self.decode(context)

        send(context, todo={'app:show': {'msg': self.acv(context)}})


"""
    加密机篇
"""


def encrypt(protocol: str):
    return Encryptor(protocol)


class Encryptor(object):
    def __init__(self, protocol):
        self._protocol = ProClazz(protocol)
        self._operation = None
        self._parameter = None
        self._result = None

    def operation(self, op: str):
        self._operation = op
        return self

    def parameter(self, param=None):
        self._parameter = param
        return self

    def handle(self, context: Context):
        try:
            if self._parameter is None:
                self._parameter = {}
            self._parameter = context.runtime.steps[context.runtime.step - 1]['result']
            self._parameter['session_key'] = context.test_sn
        except:
            pass

        logger.info(
            '~ @EM-> protocol:{} operation:{} parameter:{}'.format(self._protocol, self._operation, self._parameter))
        self._result = em.handle(self._protocol.name, self._operation, self._parameter)
        logger.info('~ @EM<- protocol:{} operation:{} result:{}'.format(self._protocol, self._operation, self._result))
        self._flush(context)

    def _flush(self, context: Context):
        context.runtime.steps.update({context.runtime.step: func.to_dict(obj='em', op=self._operation
                                                                         , parameter=self._parameter,
                                                                         result=self._result)})

    def acv(self, context: Context):
        data = func.to_dict(result=self._result)

        logger.info('~ @ACD-> module:{} function:{} parameter:{}'.format(
            self._protocol.name, self._operation, self._parameter))
        result = udm.handle(module='em.{}'.format(self._protocol.name), function=self._operation
                            , data=data, debug_url=context.acd_url)
        logger.info('~ @ACD<- module:{} function:{} result:{}'.format(self._protocol.name, self._operation, result))

        context.runtime.acvs[context.runtime.step] = result

        return result

    def exec(self, context: Context):
        self.handle(context)
        send(context, todo={'app:show': {'msg': self.acv(context)}})


"""
    表台篇
"""


def bench():
    return Bench()


class Bench(object):
    def __init__(self):
        self._operation = None
        self._parameter = None
        self._function = None
        self._interval = None
        self._result = None
        self._exec_times = 0
        self._sleep = 0
        self._func = None
        self._expect_result = None
        self._func_parameter = {}

    def operation(self, command: str):
        self._operation = command
        return self

    def parameter(self, param=None):
        self._parameter = param
        return self

    def function(self, f=None):
        self._function = f
        return self

    def sleep(self, sec=0):
        self._sleep = sec
        return self

    def interval(self, times=0):
        self._interval = times
        return self

    def compare(self, data):
        self._func = data.get('code')
        self._expect_result = data.get('expect_result', None)
        self._func_parameter = data.get('parameter', {})

        return self

    def encode(self, context: Context):
        logger.info(
            '~ @BENCH-> manufacture:{} operation:{} parameter:{}'.format(context.bench.manufacture, self._operation,
                                                                         self._parameter))

        if type(self._parameter) is dict:
            self._parameter = _replace_bench0(context, self._parameter)
        if self._function is not None and len(self._function) > 0:
            self._build_in(context)

    def decode(self, context: Context):
        logger.info('~ @BENCH<- manufacture:{} operation:{} result:{}'.format(context.bench.manufacture,
                                                                              self._operation, self._result))

        self._result = self._result.get('result')
        self._flush(context)

    def _build_in(self, context: Context):
        logger.info('~ @BUILTIN-> module:{} parameter:{}'.format('bench', self._parameter))
        for op, d in self._function.items():
            v_data = build_in.handle(module='bench', function=op, data=func.to_dict(
                param=d, iabc=context.meter.iabc, voltage=context.meter.rated_voltage,
                current=context.meter.rated_current, index=self._exec_times))
            self._parameter = _replace_bench1(self._parameter, v_data)

        logger.info('~ @BUILTIN<- module:{} parameter:{}'.format('bench', self._parameter))

    def acv(self, context: Context):
        result = str(self._result)
        data = func.to_dict(result=self._result)
        if self._func is not None:
            if type(self._func_parameter) is dict:
                data['parameter'] = _replace_bench0(context, self._func_parameter)
            try:
                if self._expect_result is None:
                    data['expect_result'] = context.runtime.steps[context.runtime.step - 1]
                else:
                    data['expect_result'] = context.runtime.steps[int(self._expect_result)]
            except:
                pass

            logger.info('~ @ACD-> module:{} function:{} parameter:{}'.format('bench', self._func, data['parameter']))
            result = udm.handle(module='bench', function=self._func, data=data, debug_url=context.acd_url)
            logger.info('~ @ACD<- module:{} function:{} result:{}'.format('bench', self._func, result))

            context.runtime.acvs[context.runtime.step] = result

        return result

    def _flush(self, context: Context):
        context.runtime.steps.update({context.runtime.step: func.to_dict(obj='bench', op=self._operation
                                                                         , parameter=self._parameter,
                                                                         result=self._result)})

    def rest(self, context: Context):
        if self._sleep > 0:
            send(context, todo={'app:show': {'msg': '系统休眠{}秒, 等待表台调整完毕...'.format(self._sleep)}})
            sleep(self._sleep)

    def _times(self, context: Context):
        if self._interval > 0:
            if context.runtime.loop_index == 0 or (context.runtime.loop_index + 1) % self._interval != 0:
                return

        self._exec_times += 1

    def exec(self, context: Context):
        if context.meter.index == 0:
            self._times(context)

            self.encode(context)
            self._result = send(context, todo={'bench:{}'.format(self._operation): self._parameter})
            self.decode(context)

            send(context, todo={'app:show': {'msg': self.acv(context)}})

            self.rest(context)


"""
    测试终端篇
"""


def client():
    return App()


class App(object):
    def __init__(self):
        self._name = 'app'
        self._operation = None
        self._message = None
        self._parameter = None

    def operation(self, command: str):
        self._operation = command
        return self

    def message(self, msg):
        self._message = {'msg': msg}
        return self

    def parameter(self, param=None):
        self._parameter = param
        return self

    def show(self, context: Context, types=2):
        logger.info('~ @APP-> operation:{} message:{}'.format('show', self._message))
        send(context, todo={'{}:{}'.format(self._name, 'show'): self._message}, types=types)

    def error(self, context: Context, types=2):
        logger.info('~ @APP-> operation:{} message:{}'.format('error', self._message))
        send(context, todo={'{}:{}'.format(self._name, 'error'): self._message}, types=types)

    def exec(self, context: Context):
        logger.info('~ @APP-> operation:{} message:{}'.format(self._operation, self._message))
        send(context, todo={'{}:{}'.format(self._name, self._operation): self._message})


"""
    平台篇
"""


def ats():
    return ATS()


class ATS(object):
    def __init__(self):
        self._name = 'ats'
        self._operation = None
        self._parameter = None

    def operation(self, command: str):
        self._operation = command
        return self

    def parameter(self, param=None):
        self._parameter = param
        return self

    def exec(self, context: Context):
        logger.info('~ @ATS-> operation:{} parameter:{}'.format(self._operation, self._parameter))
        return eval('{}(context, {})'.format(self._operation, self._parameter))



from ats_base.service import mm

from ats_case.common.enum import WorkMode, ScriptClazz


class Context(object):
    """
    测试用例上下文
    """

    def __init__(self, sn):
        self._test_sn = sn
        self._parse()

    def _parse(self):
        tl = mm.Dict.get("test:log", self._test_sn)

        self._renew = tl.get('renew', 0)
        self._mode = WorkMode(tl.get('mode'))
        self._tester = self.Tester(tl.get('tester'))
        self._case = self.Case(tl.get('usercase'))
        self._meter = self.Meter(tl.get('meter'))
        self._bench = self.Bench(tl.get('bench'))
        # 运行时
        self._runtime = self.Runtime()
        self._session = self.Session(self)
        # Debug模式 - 测试开发人员本机调试数据比对服务使用
        self._acd_url = tl.get('acd_url')

    @property
    def mode(self):
        return self._mode

    @property
    def renew(self):
        return self._renew

    @property
    def test_sn(self):
        return self._test_sn

    @property
    def tester(self):
        return self._tester

    @property
    def bench(self):
        return self._bench

    @property
    def case(self):
        return self._case

    @property
    def meter(self):
        return self._meter

    @property
    def runtime(self):
        return self._runtime

    @property
    def session(self):
        return self._session

    @property
    def acd_url(self):
        return self._acd_url

    class Tester(object):
        def __init__(self, data: dict):
            self._ip = data.get('ip')
            self._port = data.get('port')
            self._username = data.get('username')
            self._hostname = data.get('hostname')

        @property
        def ip(self):
            return self._ip

        @property
        def port(self):
            return self._port

        @property
        def username(self):
            return self._username

        @property
        def hostname(self):
            return self._hostname

        @property
        def api(self):
            return "http://{}:{}/accept".format(self.ip, self.port)

    class Bench(object):
        def __init__(self, data: dict):
            if data is not None and len(data) > 0:
                self._manufacture = data.get('manufacture', '')
                self._model = data.get('model', '')
                self._port = data.get('port', 0)
                self._error_threshold = data.get('error_threshold', 0)

        #         self._iabc = data.get('iabc', 'H')
        #
        @property
        def manufacture(self):
            return self._manufacture

        @property
        def model(self):
            return self._model

        @property
        def port(self):
            return self._port

        @property
        def error_threshold(self):
            return self._error_threshold

    class Case(object):
        def __init__(self, data: dict):
            self._id = data.get('id', -1)
            self._name = data.get('name', 'test')
            self._code = data.get('code')
            self._version = data.get('version')
            #         self._scope = data.get('scope')
            #         self._purpose = data.get('purpose')
            self._script = ScriptClazz(data.get('script', 1))
            self._control = data.get('control', {})
            self._steps = data.get('steps')

            if self._code is not None:
                self._name = '{}_{}'.format(self._name, self._code)
            if self._version is not None:
                self._name = '{}_{}'.format(self._name, self._version)

        #         self._script = 'script.{}'.format(data.get('script'))
        #         self._bench_step_orders = data.get('bench_step_orders', [])
        #         # 用户发起的参数
        #         self._req_params = self.ReqParams(data.get('req_params'))
        #
        #         lps = data.get('loops')
        #         if lps is not None and lps != '':
        #             self._loops = []
        #             lps = eval(data.get('loops'))
        #             if type(lps) is list:
        #                 for lp in lps:
        #                     self._loops.append(self.Loop(lp))
        #
        #             if self._script is None:
        #                 raise Exception('Path of script file is null.')
        #             pfs = self._script.split('.')
        #             pfs[-1] = '{}.py'.format(pfs[-1])
        #             if not util.exist(*pfs):
        #                 raise Exception('Script file[{}] is not exist.'.format(self._script))

        @property
        def id(self):
            return self._id

        @property
        def name(self):
            return self._name

        @property
        def script(self):
            return self._script

        @property
        def control(self):
            return self._control

        @property
        def steps(self):
            return self._steps

        # @property
        # def code(self):
        #     return self._code
        #
        # @property
        # def version(self):
        #     return self._version
    #
    #     @property
    #     def scope(self):
    #         return self._scope
    #
    #     @property
    #     def purpose(self):
    #         return self._purpose
    #
    #     @property
    #     def loops(self):
    #         return self._loops
    #
    #     @property
    #     def script(self):
    #         return self._script
    #
    #     @property
    #     def bench_step_orders(self):
    #         return self._bench_step_orders
    #
    #     @property
    #     def req_params(self):
    #         return self._req_params

    class Meter(object):
        def __init__(self, data: dict):
            self._index = data.get('index', 0)
            self._pos = data.get('pos')
            self._addr = data.get('addr')
            self._no = data.get('no')
            self._protocol = data.get('protocol')
            self._model = data.get('model')
            self._connect = data.get('connect')
            self._rated_voltage = data.get('rated_voltage')
            self._rated_current = data.get('rated_current')
            self._max_current = data.get('max_current')
            self._min_current = data.get('min_current')
            self._transfer_current = data.get('transfer_current')
            self._starting_current = data.get('starting_current')
            self._frequency = data.get('frequency')
            self._mconst = data.get('mconst')
            self._mpluse = data.get('mpluse')
            self._iabc = 'H'

            if self._connect == 0:
                self._iabc = 'A'

        #         self._channel = {'RS485': data.get('baudrate_485'), 'IR': data.get('baudrate_ir'),
        #                          'PLC': data.get('baudrate_plc')}
        #
        #     def get_channel(self, c: CHANNEL):
        #         return func.to_dict(type=c.value, baudrate=self._channel.get(c.value))

        @property
        def index(self):
            return self._index

        @property
        def pos(self):
            return self._pos

        @property
        def addr(self):
            return self._addr

        @property
        def no(self):
            return self._no

        @property
        def protocol(self):
            return self._protocol

        @property
        def model(self):
            return self._model

        @property
        def connect(self):
            return self._connect

        @property
        def rated_voltage(self):
            return self._rated_voltage

        @property
        def rated_current(self):
            return self._rated_current

        @property
        def max_current(self):
            return self._max_current

        @property
        def min_current(self):
            return self._min_current

        @property
        def transfer_current(self):
            return self._transfer_current

        @property
        def starting_current(self):
            return self._starting_current

        @property
        def frequency(self):
            return self._frequency

        @property
        def mconst(self):
            return self._mconst

        @property
        def mpluse(self):
            return self._mpluse

        @property
        def iabc(self):
            return self._iabc

    class Runtime(object):
        """
        运行时
        """

        def __init__(self):
            self._step = -1
            self._loop_sn = 0
            self._loop_start_step = 0
            self._loop_end_step = 0
            self._loop_count = 0
            self._loop_index = 0
            self._steps = {}
            # 多帧时使用
            self._final_result = None
            # 对比结果 - 用例结束时统计执行结果
            self._acvs = {}

        def acv_result(self):
            sc = fc = 0
            fs = []
            for s, result in self.acvs.items():
                if str(result).find('不合格') >= 0:
                    fc += 1
                    fs.append(str(s))
                else:
                    sc += 1

            msg = '步骤: {}步\r\n'.format(len(self._acvs))
            msg += '合格: {}步\r\n'.format(sc)
            msg += '不合格: {}步 ~ {}\r\n'.format(fc, ','.join(fs))

            return msg

        @property
        def step(self):
            return self._step

        @step.setter
        def step(self, value):
            self._step = value

        @property
        def loop_sn(self):
            return self._loop_sn

        @loop_sn.setter
        def loop_sn(self, value):
            self._loop_sn = value

        @property
        def loop_start_step(self):
            return self._loop_start_step

        @loop_start_step.setter
        def loop_start_step(self, value):
            self._loop_start_step = value

        @property
        def loop_end_step(self):
            return self._loop_end_step

        @loop_end_step.setter
        def loop_end_step(self, value):
            self._loop_end_step = value

        @property
        def loop_count(self):
            return self._loop_count

        @loop_count.setter
        def loop_count(self, value):
            self._loop_count = value

        @property
        def loop_index(self):
            return self._loop_index

        @loop_index.setter
        def loop_index(self, value):
            self._loop_index = value

        @property
        def steps(self):
            return self._steps

        @property
        def final_result(self):
            return self._final_result

        @final_result.setter
        def final_result(self, value):
            self._final_result = value

        @property
        def acvs(self):
            return self._acvs

        @acvs.setter
        def acvs(self, value):
            self._acvs = value

    class Session(object):
        def __init__(self, parent):
            self._parent = parent

        def get(self, name: str, key: str):
            return mm.Dict.get('{}:{}'.format(self._parent.test_sn, name), key)

        def set(self, name: str, key: str, data):
            return mm.Dict.put('{}:{}'.format(self._parent.test_sn, name), key, data)



import psutil

from multiprocessing import Process

from ats_base.service import mm
from ats_base.log.logger import logger
from ats_case.manage.start import run


def start(data):
    """
    启动测试进程
    :param data:
    :return:
    """
    # 判断测试终端是否可以连接
    p = Process(target=run, kwargs=data)
    p.start()

    logger.info('TEST PROCESS[{}] START - DATA: {}...'.format(p.pid, data))
    return p.pid


def suspend(data):
    """
    暂停测试进程
    :param data:
    :return:
    """
    pid = data.get('pid')
    logger.info('TEST PROCESS[{}] SUSPEND...'.format(pid))

    p = psutil.Process(pid)
    p.suspend()


def resume(data):
    """
    恢复暂停测试进程
    :param data:
    :return:
    """
    pid = data.get('pid')
    logger.info('TEST PROCESS[{}] RESUME...'.format(pid))

    p = psutil.Process(pid)
    p.resume()


def cancel(data):
    """
    结束测试进程
    :param data:
    :return:
    """
    pid = data.get('pid')
    logger.info('TEST PROCESS[{}] CANCEL...'.format(pid))

    p = psutil.Process(pid)
    p.kill()


def callback(host: str, csn: str, data):
    """
    回调
    :param host:
    :param csn:
    :param data:
    :return:
    """
    mm.Dict.put(host, csn, data.get('data'))
    logger.info('CALLBACK HOST[{}] CSN[{}] - DATA: {}...'.format(host, csn, data))




import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="ats_case",
    version="0.8.5",
    py_modules=['ats_case'],
    author="zhangyue",
    author_email="zhangyue@techen.cn",
    description="Test Script Development Library",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitee.com/henry9000/ats_case",
    project_urls={
        "Bug Tracker": "https://gitee.com/henry9000/ats_case/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=setuptools.find_packages(),
    python_requires=">=3.9",
    install_requires=["pytest", "pytest-ordering", "psutil", "gevent", "ats-base"],
    package_data={
        '': ['*.tmp'],
    },
)
